@@ -2,19 +2,19 @@
   This file is part of "Scopa" - An italian card game.
   Copyright (C) 2007  Tim Teulings
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
+  This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
 #include "PlayerJudge.h"
@@ -120,7 +120,8 @@ int JudgePlayer::GetRatingForSolution(const SolutionSet& solution,
                                       const std::vector<Card>& yourCards,
                                       size_t recursion,
                                       size_t maxRecursion,
-                                      bool isme) const
+                                      bool isme,
+                                      bool allowOnlySimplestCombo) const
 {
   int tmpRating;
 
@@ -207,7 +208,7 @@ int JudgePlayer::GetRatingForSolution(const SolutionSet& solution,
   int                                   averageRating=0;
 
 
-  Table::Calculate(newTable,newCombinations,newPoints);
+  Table::Calculate(newTable,newCombinations,newPoints,allowOnlySimplestCombo);
   Table::GetSolutionSets(newHand,newTable,newCombinations,newPoints,newSolutions);
 
   for (size_t t=0; t<newSolutions.size(); t++) {
@@ -238,7 +239,8 @@ int JudgePlayer::GetRatingForSolution(const SolutionSet& solution,
                                       yourCards,
                                       recursion+1,
                                       maxRecursion,
-                                      !isme);
+                                      !isme,
+                                      allowOnlySimplestCombo);
     }
     else {
       newHand=hand;
@@ -254,7 +256,8 @@ int JudgePlayer::GetRatingForSolution(const SolutionSet& solution,
                                       newCards,
                                       recursion+1,
                                       maxRecursion,
-                                      !isme);
+                                      !isme,
+                                      allowOnlySimplestCombo);
     }
 
 
@@ -312,7 +315,8 @@ SolutionSet JudgePlayer::PlayCard(const Table& table, size_t round)
                                    yourCards,
                                    0,
                                    2,
-                                   true);
+                                   true,
+                                   table.AllowOnlySimplestCombo());
 
     //std::cout << "Playing " << Lum::Base::WStringToString(solutions[s].yours.GetName()) << " ==> " << tmpRating << std::endl;
 
