@@ -2,19 +2,19 @@
   This file is part of "Scopa" - An italian card game.
   Copyright (C) 2007  Tim Teulings
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
+  This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
 
@@ -25,9 +25,11 @@
 #include <Lum/Base/String.h>
 
 #include <Lum/Def/Menu.h>
+#include <Lum/Def/Props.h>
 
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
+#include <Lum/Dlg/Properties.h>
 
 #include <Lum/Images/Loader.h>
 
@@ -53,6 +55,9 @@
 #include "PlayerRandom.h"
 #include "Result.h"
 
+// Configuration
+#include "Configuration.h"
+
 // GUI
 #include "CardArea.h"
 #include "ChooseMoveDialog.h"
@@ -78,6 +83,7 @@ private:
 
 private:
   Lum::Model::ActionRef newGameAction;
+  Lum::Model::ActionRef settingsAction;
   Lum::Model::ActionRef lastHumanMoveAction;
   Lum::Model::ActionRef lastComputerMoveAction;
   Lum::Model::ActionRef aboutAction;
@@ -102,7 +108,7 @@ private:
   size_t                globalPoints[2];
   std::vector<Result>   result;
   Heap                  *heap;
-  Table                 *table;
+  Table                 table;
   std::vector<Move>     lastHumanMove;
   std::vector<Move>     lastComputerMove;
   std::vector<Card>     currentComputerMove;
@@ -118,6 +124,7 @@ private:
 public:
   MainDialog()
   : newGameAction(new Lum::Model::Action()),
+    settingsAction(new Lum::Model::Action()),
     lastHumanMoveAction(new Lum::Model::Action()),
     lastComputerMoveAction(new Lum::Model::Action()),
     aboutAction(new Lum::Model::Action()),
@@ -125,7 +132,6 @@ public:
     handFadedAction(new Lum::Model::Action()),
     tableFadedAction(new Lum::Model::Action()),
     heap(new Heap()),
-    table(new Table()),
     computerPlayer(1),
     winningPoints(11)
   {
@@ -133,8 +139,10 @@ public:
     lastComputerMoveAction->Disable();
 
     Observe(GetOpenedAction());
+    Observe(GetClosedAction());
 
     Observe(newGameAction);
+    Observe(settingsAction);
     Observe(lastHumanMoveAction);
     Observe(lastComputerMoveAction);
     Observe(aboutAction);
@@ -143,6 +151,8 @@ public:
     Observe(handFadedAction);
     Observe(tableFadedAction);
 
+    Observe(allowOnlySimplestCombo);
+
     Lum::Base::Path path;
 
     path.SetNativeDir(L"cards");
@@ -314,6 +324,8 @@ public:
                                 .SetShortcut(Lum::OS::qualifierControl,L"c"),
                                 lastComputerMoveAction)
                .SetOpensDialog())
+      ->Separator()
+      ->ActionSettings(settingsAction)
     ->End()
     ->GroupHelp()
       //->ActionHelp()
@@ -349,6 +361,7 @@ public:
       break;
     }
 #endif
+
     switch (state) {
     case stateHumanFading:
       handFaded=false;
@@ -375,7 +388,7 @@ public:
         break;
       }
     }
-    tableView->SetCards(table->table,true);
+    tableView->SetCards(table.table,true);
   }
 
   void UpdateDisplay()
@@ -468,26 +481,26 @@ public:
 
     // The rest of the cards on the table belong to the player that collected the last cards
 
-    if (!table->IsEmpty()) {
+    if (!table.IsEmpty()) {
 #if defined(PRINT_DEBUG)
       std::cout << "--- Final" << std::endl;
       std::cout << "Player " << lastExchange+1 << " gets the rest of the cards on the table:" << std::endl;
 
-      for (size_t i=0; i<table->table.size(); i++) {
-        std::cout << "* "<< Lum::Base::WStringToString(table->table[i].GetName()) << std::endl;
+      for (size_t i=0; i<table.table.size(); i++) {
+        std::cout << "* "<< Lum::Base::WStringToString(table.table[i].GetName()) << std::endl;
       }
 #endif
 
-      result[lastExchange%2].AddToCollected(table->table,false);
+      result[lastExchange%2].AddToCollected(table.table,false);
 
       if (dynamic_cast<HumanPlayer*>(players[lastExchange%2])!=NULL) {
-        lastHumanMove[0]=Move(table->table,false);
+        lastHumanMove[0]=Move(table.table,false);
       }
       else {
-        lastComputerMove[0]=Move(table->table,false);
+        lastComputerMove[0]=Move(table.table,false);
       }
 
-      table->table.clear();
+      table.table.clear();
 
       UpdateDisplay();
     }
@@ -570,7 +583,7 @@ public:
     currentComputerMoveMove=0;
 
     std::vector<Card> tmp;
-    SolutionSet       solution=players[currentPlayer]->PlayCard(*table,currentRound);
+    SolutionSet       solution=players[currentPlayer]->PlayCard(table,currentRound);
 
     players[currentPlayer]->hand.erase(players[currentPlayer]->hand.begin()+solution.yoursPos);
 
@@ -586,7 +599,7 @@ public:
 
     currentComputerMoveMove=solution.solution;
 
-    tmp=table->table;
+    tmp=table.table;
     tmp.push_back(solution.yours);
 
     tableView->SetCards(tmp,true);
@@ -597,7 +610,7 @@ public:
     Card              card=currentComputerMove[0];
     std::vector<Card> collected;
 
-    collected=table->PutCard(card,currentComputerMoveMove);
+    collected=table.PutCard(card,currentComputerMoveMove);
 
     if (lastComputerMove.empty()) {
       if (collected.empty()) {
@@ -630,7 +643,7 @@ public:
                                 currentRound);
       }
 
-      if (table->IsEmpty()) {
+      if (table.IsEmpty() && currentRound!=18) {
 #if defined(PRINT_DEBUG)
         std::cout << "=>>> SCOPA!" << std::endl;
 #endif
@@ -640,7 +653,7 @@ public:
       lastExchange=currentPlayer;
     }
 
-    result[currentPlayer%2].AddToCollected(collected,table->IsEmpty());
+    result[currentPlayer%2].AddToCollected(collected,table.IsEmpty());
 
     OnPlayerPlayed();
   }
@@ -659,10 +672,10 @@ public:
     std::cout << "Human player plays " << Lum::Base::WStringToString(card.GetName()) <<std::endl;
 #endif
 
-    if (table->HasValueMultipleCollectionSets(card.GetValue())) {
+    if (table.HasValueMultipleCollectionSets(card.GetValue())) {
       std::vector<std::vector<Card> > moves;
 
-      table->GetMoves(card.GetValue(),moves);
+      table.GetMoves(card.GetValue(),moves);
 
 #if defined(PRINT_DEBUG)
       std::cout << "Card played by human has multiple collection sets!" << std::endl;
@@ -670,7 +683,7 @@ public:
       move=GetMove(this,card,moves,images);
     }
 
-    collected=table->PutCard(card,move);
+    collected=table.PutCard(card,move);
 
     if (lastHumanMove.empty()) {
       if (collected.empty()) {
@@ -703,7 +716,7 @@ public:
                                 currentRound);
       }
 
-      if (table->IsEmpty()) {
+      if (table.IsEmpty() && currentRound!=18) {
 #if defined(PRINT_DEBUG)
         std::cout << "=>>> SCOPA!" << std::endl;
 #endif
@@ -714,7 +727,7 @@ public:
     }
 
 
-    result[currentPlayer%2].AddToCollected(collected,table->IsEmpty());
+    result[currentPlayer%2].AddToCollected(collected,table.IsEmpty());
 
     OnPlayerPlayed();
   }
@@ -810,7 +823,7 @@ public:
       initialCards.push_back(heap->GetCard());
     }
 
-    table->Initialize(initialCards);
+    table.Initialize(initialCards);
 
     currentGame++;
     currentRound=1;
@@ -870,28 +883,58 @@ public:
     OnNewRound();
   }
 
+  void ShowSettings()
+  {
+    Lum::Def::PropGroup *props=new Lum::Def::PropGroup();
+
+    props->Boolean(Lum::Def::Boolean(Lum::Def::Desc(_(L"OPTION_ONLY_SIMPLEST_COMBO",
+                                                      L"Only simplest take allowed")),
+                                     ::allowOnlySimplestCombo));
+
+    Lum::Dlg::Properties::Show(this,props);
+
+    delete props;
+  }
+
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
   {
-    if (model==GetOpenedAction() && GetOpenedAction()->IsFinished()) {
+    if (model==GetOpenedAction() &&
+        GetOpenedAction()->IsFinished()) {
+      LoadConfig();
     }
-    else if (model==newGameAction && newGameAction->IsFinished()) {
+    if (model==GetClosedAction() &&
+        GetClosedAction()->IsFinished()) {
+      SaveConfig();
+    }
+    else if (model==newGameAction &&
+             newGameAction->IsFinished()) {
       OnNewGame();
     }
-    else if (model==lastComputerMoveAction && lastComputerMoveAction->IsFinished()) {
+    else if (model==settingsAction &&
+             settingsAction->IsFinished()) {
+      ShowSettings();
+    }
+    else if (model==lastComputerMoveAction &&
+             lastComputerMoveAction->IsFinished()) {
       ShowMove(this,true,lastComputerMove[0],images);
     }
-    else if (model==lastHumanMoveAction && lastHumanMoveAction->IsFinished()) {
+    else if (model==lastHumanMoveAction &&
+             lastHumanMoveAction->IsFinished()) {
       ShowMove(this,false,lastHumanMove[0],images);
     }
-    else if (model==aboutAction && aboutAction->IsFinished()) {
+    else if (model==aboutAction &&
+             aboutAction->IsFinished()) {
       Lum::Dlg::About::Show(this,info);
     }
-    else if (model==handSelectionAction && handSelectionAction->IsFinished() && state==stateHumanMove) {
+    else if (model==handSelectionAction &&
+             handSelectionAction->IsFinished() &&
+             state==stateHumanMove) {
       const CardArea::Selection &selection=dynamic_cast<const CardArea::Selection&>(msg);
 
       OnPlayHuman(selection.GetCardIndex());
     }
-    else if (model==handFadedAction && handFadedAction->IsFinished()) {
+    else if (model==handFadedAction &&
+             handFadedAction->IsFinished()) {
       handFaded=true;
       if (state==stateHumanFading) {
         if (handFaded && tableFaded) {
@@ -899,7 +942,8 @@ public:
         }
       }
     }
-    else if (model==tableFadedAction && tableFadedAction->IsFinished()) {
+    else if (model==tableFadedAction &&
+             tableFadedAction->IsFinished()) {
       tableFaded=true;
       if (state==stateHumanFading) {
         if (handFaded && tableFaded) {
@@ -912,6 +956,9 @@ public:
         }
       }
     }
+    else if (model==allowOnlySimplestCombo) {
+      table.SetAllowOnlySimplestCombo(allowOnlySimplestCombo->Get());
+    }
 
     Dialog::Resync(model,msg);
   }
@@ -922,6 +969,10 @@ class Main : public Lum::GUIApplication<MainDialog>
 public:
   bool Initialize()
   {
+#if defined(APP_DATADIR)
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+#endif
+
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
     info.SetDescription(_(L"ABOUT_DESC",L"Play a game of scopa with me..."));
@@ -929,10 +980,6 @@ public:
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2007, Tim Teulings");
     info.SetLicense(L"GNU Public License");
-  
-#if defined(APP_DATADIR)
-    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
-#endif
 
     srand(time(NULL));
 
