@@ -2,19 +2,19 @@
   This file is part of "Scopa" - An italian card game.
   Copyright (C) 2007  Tim Teulings
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
+  This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
 #include "Table.h"
@@ -30,9 +30,16 @@ bool SolutionSet::IsTrick() const
   return table.size()>0;
 }
 
+Table::Table()
+: allowOnlySimplestCombo(true)
+{
+  // no code
+}
+
 void Table::Calculate(const std::vector<Card>& table,
                       std::vector<std::vector<size_t> >& combinations,
-                      std::map<size_t,std::vector<size_t> >& points)
+                      std::map<size_t,std::vector<size_t> >& points,
+                      bool allowOnlySimplestCombo)
 {
   size_t last,start,stop,max;
 
@@ -86,15 +93,18 @@ void Table::Calculate(const std::vector<Card>& table,
       value+=table[combinations[i][j]-1].GetValue();
     }
 
-    // Only add solutions if we don't have a solution or the size of the solution
-    // set is not bigger than the existing solution.
-    // Note, that the array combinations is sorted by increasing solution size, so
-    // that we will not insert smaller solution if we already have found one!
-    std::map<size_t,std::vector<size_t> >::const_iterator pv;
+    if (allowOnlySimplestCombo) {
+      // Only add solutions if we don't have a solution or the size of the solution
+      // set is not bigger than the existing solution.
+      // Note, that the array combinations is sorted by increasing solution size, so
+      // that we will not insert smaller solution if we already have found one!
+      std::map<size_t,std::vector<size_t> >::const_iterator pv;
 
-    pv=points.find(value);
-    if (pv!=points.end() && combinations[i].size()>combinations[pv->second[0]].size()) {
-      continue;
+      pv=points.find(value);
+      if (pv!=points.end() &&
+          combinations[i].size()>combinations[pv->second[0]].size()) {
+        continue;
+      }
     }
 
     points[value].push_back(i);
@@ -148,7 +158,10 @@ void Table::GetSolutionSets(const std::vector<Card>& hand,
 
 void Table::Calculate()
 {
-  Calculate(table,combinations,points);
+  Calculate(table,
+            combinations,
+            points,
+            allowOnlySimplestCombo);
 }
 
 void Table::Initialize(const std::vector<Card>& initialCards)
@@ -158,6 +171,16 @@ void Table::Initialize(const std::vector<Card>& initialCards)
   Calculate();
 }
 
+void Table::SetAllowOnlySimplestCombo(bool allow)
+{
+  allowOnlySimplestCombo=allow;
+}
+
+bool Table::AllowOnlySimplestCombo() const
+{
+  return allowOnlySimplestCombo;
+}
+
 bool Table::IsEmpty() const
 {
   return table.empty();
@@ -222,9 +245,14 @@ std::vector<Card> Table::PutCard(const Card& card, size_t solution)
   return result;
 }
 
-void Table::GetSolutionSets(const std::vector<Card>& hand, std::vector<SolutionSet>& solutions) const
+void Table::GetSolutionSets(const std::vector<Card>& hand,
+                            std::vector<SolutionSet>& solutions) const
 {
-  GetSolutionSets(hand,table,combinations,points,solutions);
+  GetSolutionSets(hand,
+                  table,
+                  combinations,
+                  points,
+                  solutions);
 }
 
 size_t Table::GetValueOnTable() const
