@@ -5,19 +5,19 @@
   This file is part of "Scopa" - An italian card game.
   Copyright (C) 2007  Tim Teulings
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-  This library is distributed in the hope that it will be useful,
+  This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
 #include <map>
@@ -46,11 +46,13 @@ public:
   std::vector<Card>                      table;         //! The cards on the table
   std::vector<std::vector<size_t> >      combinations;  //! The list of allowed combinations
   std::map<size_t,std::vector<size_t> >  points;        //! The reference of combinations for a specific value
+  bool                                   allowOnlySimplestCombo; //! Only the combination with the minimum cards for a value is allowed
 
 public:
   static void Calculate(const std::vector<Card>& table,
                         std::vector<std::vector<size_t> >& combinations,
-                        std::map<size_t,std::vector<size_t> >& points);
+                        std::map<size_t,std::vector<size_t> >& points,
+                        bool allowOnlySimplestCombo);
   static void GetSolutionSets(const std::vector<Card>& hand,
                               const std::vector<Card>& table,
                               const std::vector<std::vector<size_t> >& combinations,
@@ -61,8 +63,13 @@ private:
   void Calculate();
 
 public:
+  Table();
+
   void Initialize(const std::vector<Card>& initialCards);
 
+  void SetAllowOnlySimplestCombo(bool allow);
+  bool AllowOnlySimplestCombo() const;
+
   bool IsEmpty() const;
 
   bool HasValueMultipleCollectionSets(size_t value) const;
